@@ -1,5 +1,72 @@
 import platform,time,threading
 
+MONITOR_MANUFACTURER_CODES = {
+    "AAC": "AcerView",
+    "ACR": "Acer",
+    "AOC": "AOC",
+    "AIC": "AG Neovo",
+    "APP": "Apple Computer",
+    "AST": "AST Research",
+    "AUO": "Asus",
+    "BNQ": "BenQ",
+    "CMO": "Acer",
+    "CPL": "Compal",
+    "CPQ": "Compaq",
+    "CPT": "Chunghwa Pciture Tubes, Ltd.",
+    "CTX": "CTX",
+    "DEC": "DEC",
+    "DEL": "Dell",
+    "DPC": "Delta",
+    "DWE": "Daewoo",
+    "EIZ": "EIZO",
+    "ELS": "ELSA",
+    "ENC": "EIZO",
+    "EPI": "Envision",
+    "FCM": "Funai",
+    "FUJ": "Fujitsu",
+    "FUS": "Fujitsu-Siemens",
+    "GSM": "LG Electronics",
+    "GWY": "Gateway 2000",
+    "HEI": "Hyundai",
+    "HIT": "Hyundai",
+    "HSL": "Hansol",
+    "HTC": "Hitachi/Nissei",
+    "HWP": "HP",
+    "IBM": "IBM",
+    "ICL": "Fujitsu ICL",
+    "IVM": "Iiyama",
+    "KDS": "Korea Data Systems",
+    "LEN": "Lenovo",
+    "LGD": "Asus",
+    "LPL": "Fujitsu",
+    "MAX": "Belinea",
+    "MEI": "Panasonic",
+    "MEL": "Mitsubishi Electronics",
+    "MS_": "Panasonic",
+    "NAN": "Nanao",
+    "NEC": "NEC",
+    "NOK": "Nokia Data",
+    "NVD": "Fujitsu",
+    "OPT": "Optoma",
+    "PHL": "Philips",
+    "REL": "Relisys",
+    "SAN": "Samsung",
+    "SAM": "Samsung",
+    "SBI": "Smarttech",
+    "SGI": "SGI",
+    "SNY": "Sony",
+    "SRC": "Shamrock",
+    "SUN": "Sun Microsystems",
+    "SEC": "Hewlett-Packard",
+    "TAT": "Tatung",
+    "TOS": "Toshiba",
+    "TSB": "Toshiba",
+    "VSC": "ViewSonic",
+    "ZCM": "Zenith",
+    "UNK": "Unknown",
+    "_YV": "Fujitsu",
+}
+
 class ScreenBrightnessError(Exception):
     '''
     Generic error class designed to make catching errors under one umbrella easy.
@@ -18,12 +85,15 @@ class ScreenBrightnessError(Exception):
         self.message=message
         super().__init__(self.message)
 
-def list_monitors():
+def list_monitors(**kwargs):
     '''
-    list all monitors that are controllable by this library (not yet implemented on Linux)
+    list all monitors that are controllable by this library
+
+    Args:
+        kwargs (dict): passed directly to OS relevant monitor list function
 
     Returns:
-        list of strings (Windows) but None on Linux
+        list: list of strings
     
     Example:
         ```python
@@ -33,9 +103,9 @@ def list_monitors():
         ```
     '''
     if platform.system() == 'Windows':
-        return windows.list_monitors()
+        return windows.list_monitors(**kwargs)
     elif platform.system() == 'Linux':
-        pass #return linux.list_monitors()
+        return linux.list_monitors(**kwargs)
 
 def flatten_list(thick_list):
     '''
@@ -283,5 +353,5 @@ if platform.system()=='Windows':
 elif platform.system()=='Linux':
     from . import linux
 
-__version__='0.5.1'
+__version__='0.6.0'
 __author__='Crozzers'
