@@ -1,74 +1,7 @@
 import wmi, threading, pythoncom, ctypes, win32api
 from ctypes import windll, byref, Structure, WinError, POINTER, WINFUNCTYPE
 from ctypes.wintypes import BOOL, HMONITOR, HDC, RECT, LPARAM, DWORD, BYTE, WCHAR, HANDLE
-from . import flatten_list
-
-MONITOR_MANUFACTURER_CODES = {
-    "AAC": "AcerView",
-    "ACR": "Acer",
-    "AOC": "AOC",
-    "AIC": "AG Neovo",
-    "APP": "Apple Computer",
-    "AST": "AST Research",
-    "AUO": "Asus",
-    "BNQ": "BenQ",
-    "CMO": "Acer",
-    "CPL": "Compal",
-    "CPQ": "Compaq",
-    "CPT": "Chunghwa Pciture Tubes, Ltd.",
-    "CTX": "CTX",
-    "DEC": "DEC",
-    "DEL": "Dell",
-    "DPC": "Delta",
-    "DWE": "Daewoo",
-    "EIZ": "EIZO",
-    "ELS": "ELSA",
-    "ENC": "EIZO",
-    "EPI": "Envision",
-    "FCM": "Funai",
-    "FUJ": "Fujitsu",
-    "FUS": "Fujitsu-Siemens",
-    "GSM": "LG Electronics",
-    "GWY": "Gateway 2000",
-    "HEI": "Hyundai",
-    "HIT": "Hyundai",
-    "HSL": "Hansol",
-    "HTC": "Hitachi/Nissei",
-    "HWP": "HP",
-    "IBM": "IBM",
-    "ICL": "Fujitsu ICL",
-    "IVM": "Iiyama",
-    "KDS": "Korea Data Systems",
-    "LEN": "Lenovo",
-    "LGD": "Asus",
-    "LPL": "Fujitsu",
-    "MAX": "Belinea",
-    "MEI": "Panasonic",
-    "MEL": "Mitsubishi Electronics",
-    "MS_": "Panasonic",
-    "NAN": "Nanao",
-    "NEC": "NEC",
-    "NOK": "Nokia Data",
-    "NVD": "Fujitsu",
-    "OPT": "Optoma",
-    "PHL": "Philips",
-    "REL": "Relisys",
-    "SAN": "Samsung",
-    "SAM": "Samsung",
-    "SBI": "Smarttech",
-    "SGI": "SGI",
-    "SNY": "Sony",
-    "SRC": "Shamrock",
-    "SUN": "Sun Microsystems",
-    "SEC": "Hewlett-Packard",
-    "TAT": "Tatung",
-    "TOS": "Toshiba",
-    "TSB": "Toshiba",
-    "VSC": "ViewSonic",
-    "ZCM": "Zenith",
-    "UNK": "Unknown",
-    "_YV": "Fujitsu",
-}
+from . import flatten_list, MONITOR_MANUFACTURER_CODES
 
 class WMI:
     '''collection of screen brightness related methods using the WMI API'''
@@ -619,7 +552,7 @@ class Monitor(object):
 
         Args:
             args (tuple): passed directly to this monitor's brightness method
-            kwargs (dict): passed directly to this monitor's brightness method (the `display` kwarg is always overwritrten)
+            kwargs (dict): passed directly to this monitor's brightness method (the `display` kwarg is always overwritten)
 
         Returns:
             int: from 0 to 100
@@ -714,10 +647,13 @@ class Monitor(object):
         except:
             return False
 
-def list_monitors_info():
+def list_monitors_info(method=None):
     '''
     Lists detailed information about all detected monitors
 
+    Args:
+        method (str): the method the monitor can be addressed by. Can be 'wmi' or 'vcp'
+
     Returns:
         list: list of dictionaries upon success, empty list upon failure
 
@@ -732,13 +668,18 @@ def list_monitors_info():
             print('Model:', info['model']) # the general model of the display
             print('Serial:', info['serial']) # a unique string assigned by Windows to this display
             print('Manufacturer:', info['manufacturer']) # the name of the brand of the monitor
-            print('Manufacturer ID:', info['manufacturer_id']) # the 3 letter code corresponding to the breand name, EG: BNQ -> BenQ  
+            print('Manufacturer ID:', info['manufacturer_id']) # the 3 letter code corresponding to the brand name, EG: BNQ -> BenQ  
             print('Index:', info['index']) # the index of that display FOR THE SPECIFIC METHOD THE DISPLAY USES
             print('Method:', info['method']) # the method this monitor can be addressed by
         ```
     '''
     tmp = []
-    for m in [WMI, VCP]:
+    methods = [WMI,VCP]
+    if method!=None:
+        if method.lower()=='wmi':methods=[WMI]
+        elif method.lower()=='vcp':methods=[VCP]
+        else:raise ValueError('method kwarg must be \'wmi\' or \'vcp\'')
+    for m in methods:
         tmp.append(m.get_display_info())
     tmp = flatten_list(tmp)
     info = []
@@ -750,10 +691,13 @@ def list_monitors_info():
             info.append(i)
     return flatten_list(info)
 
-def list_monitors():
+def list_monitors(method=None):
     '''
     Returns a list of all addressable monitor names
 
+    Args:
+        method (str): the method the monitor can be addressed by. Can be 'wmi' or 'vcp'
+
     Returns:
         list: list of strings
 
@@ -765,14 +709,14 @@ def list_monitors():
         # EG output: ['BenQ BNQ78A7', 'Dell DEL405E']
         ```
     '''
-    displays = [i['name'] for i in list_monitors_info()]
+    displays = [i['name'] for i in list_monitors_info(method=method)]
     return flatten_list(displays)
 
 def __filter_monitors(display=None, method=None):
     '''internal function, do not call
     filters the list of all addressable monitors by:
         whether their name/model/serial/model_name matches the display kwarg
-        whether they use the method matching the mdthod kwarg'''
+        whether they use the method matching the method kwarg'''
     methods = [WMI, VCP]
     monitors = list_monitors_info()
     #parse the method kwarg
